#######################
PyDMCheckbox
#######################

.. autoclass:: pydm.widgets.checkbox.PyDMCheckbox
   :members:
   :show-inheritance:

.. note::
   See `QCheckBox Documentation <https://doc.qt.io/qtforpython-5/PySide2/QtWidgets/QCheckBox.html>`_ for all inherited properties and methods.